@@ -26,8 +26,8 @@
 #include "kamera.h"
 
 #include <QDialog>
-#include <QWidget>
-#include <QDialogButtonBox>
+class QWidget;
+class QDialogButtonBox;
 
 class KConfig;
 class QString;
@@ -100,7 +100,7 @@ protected Q_SLOTS:
 protected:
     KCamera *m_device;
 
-    bool populateCameraListView(void);
+    bool populateCameraListView();
     void setPortType(int type);
 
     // port settings widgets
